pub struct Autoscale {
pub current_slots: Option<i64>,
pub max_slots: Option<i64>,
}Expand description
Auto scaling settings.
This type is not used in any activity, and only used as part of another schema.
Fields
current_slots: Option<i64>Output only. The slot capacity added to this reservation when autoscale happens. Will be between [0, max_slots]. Note: after users reduce max_slots, it may take a while before it can be propagated, so current_slots may stay in the original value and could be larger than max_slots for that brief period (less than one minute)
max_slots: Option<i64>Optional. Number of slots to be scaled when needed.