pub struct ListCapacityCommitmentsResponse {
pub capacity_commitments: Option<Vec<CapacityCommitment>>,
pub next_page_token: Option<String>,
}Expand description
The response for ReservationService.ListCapacityCommitments.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations capacity commitments list projects (response)
Fields
capacity_commitments: Option<Vec<CapacityCommitment>>List of capacity commitments visible to the user.
next_page_token: Option<String>Token to retrieve the next page of results, or empty if there are no more results in the list.