ReplicationStatus

Struct ReplicationStatus 

pub struct ReplicationStatus {
    pub error: Option<Status>,
    pub last_error_time: Option<DateTime<Utc>>,
    pub last_replication_time: Option<DateTime<Utc>>,
    pub soft_failover_start_time: Option<DateTime<Utc>>,
}
Disaster Recovery(DR) replication status of the reservation.

This type is not used in any activity, and only used as part of another schema.

Fields

error: Option<Status>

Output only. The last error encountered while trying to replicate changes from the primary to the secondary. This field is only available if the replication has not succeeded since.

last_error_time: Option<DateTime<Utc>>

Output only. The time at which the last error was encountered while trying to replicate changes from the primary to the secondary. This field is only available if the replication has not succeeded since.

last_replication_time: Option<DateTime<Utc>>

Output only. A timestamp corresponding to the last change on the primary that was successfully replicated to the secondary.

soft_failover_start_time: Option<DateTime<Utc>>

Output only. The time at which a soft failover for the reservation and its associated datasets was initiated. After this field is set, all subsequent changes to the reservation will be rejected unless a hard failover overrides this operation. This field will be cleared once the failover is complete.