pub struct SchedulingPolicy {
pub concurrency: Option<i64>,
pub max_slots: Option<i64>,
}Expand description
The scheduling policy controls how a reservation’s resources are distributed.
This type is not used in any activity, and only used as part of another schema.
Fields
concurrency: Option<i64>Optional. If present and > 0, the reservation will attempt to limit the concurrency of jobs running for any particular project within it to the given value. This feature is not yet generally available.
max_slots: Option<i64>Optional. If present and > 0, the reservation will attempt to limit the slot consumption of queries running for any particular project within it to the given value. This feature is not yet generally available.