pub struct Assignment {
pub assignee: Option<String>,
pub enable_gemini_in_bigquery: Option<bool>,
pub job_type: Option<String>,
pub name: Option<String>,
pub scheduling_policy: Option<SchedulingPolicy>,
pub state: Option<String>,
}Expand description
An assignment allows a project to submit jobs of a certain type using slots from the specified reservation.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations reservations assignments create projects (request|response)
- locations reservations assignments move projects (response)
- locations reservations assignments patch projects (request|response)
Fields
assignee: Option<String>Optional. The resource which will use the reservation. E.g. projects/myproject, folders/123, or organizations/456.
enable_gemini_in_bigquery: Option<bool>Optional. This field controls if “Gemini in BigQuery” (https://cloud.google.com/gemini/docs/bigquery/overview) features should be enabled for this reservation assignment, which is not on by default. “Gemini in BigQuery” has a distinct compliance posture from BigQuery. If this field is set to true, the assignment job type is QUERY, and the parent reservation edition is ENTERPRISE_PLUS, then the assignment will give the grantee project/organization access to “Gemini in BigQuery” features.
job_type: Option<String>Optional. Which type of jobs will use the reservation.
name: Option<String>Output only. Name of the resource. E.g.: projects/myproject/locations/US/reservations/team1-prod/assignments/123. The assignment_id must only contain lower case alphanumeric characters or dashes and the max length is 64 characters.
scheduling_policy: Option<SchedulingPolicy>Optional. The scheduling policy to use for jobs and queries of this assignee when running under the associated reservation. The scheduling policy controls how the reservation’s resources are distributed. This overrides the default scheduling policy specified on the reservation. This feature is not yet generally available.
state: Option<String>Output only. State of the assignment.