pub struct MergeCapacityCommitmentsRequest {
pub capacity_commitment_id: Option<String>,
pub capacity_commitment_ids: Option<Vec<String>>,
}Expand description
The request for ReservationService.MergeCapacityCommitments.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
capacity_commitment_id: Option<String>Optional. The optional resulting capacity commitment ID. Capacity commitment name will be generated automatically if this field is empty. This field must only contain lower case alphanumeric characters or dashes. The first and last character cannot be a dash. Max length is 64 characters.
capacity_commitment_ids: Option<Vec<String>>Ids of capacity commitments to merge. These capacity commitments must exist under admin project and location specified in the parent. ID is the last portion of capacity commitment name e.g., ‘abc’ for projects/myproject/locations/US/capacityCommitments/abc